/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Radera"

, "Reply"
: "Svara"

, "Reply To All"
: "Svara till alla"

, "Forward"
: "Vidarebefodra"

, "Print Message"
: "Utskrifts Meddelande"

, "Print Preview"
: "Förhandsvisa"

, "Add New Account"
: "Lägg till nytt konto"

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "Semester"
 ,"Semestrar"

]
, "Account, Accounts"
: [
  "Konto"
 ,"Konton"

]
, "Account Name"
: "Kontonamn"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Användares mail-address"

, "User Name (From)"
: "Användarnamn (från)"

, "Organization"
: "Organisation"

, "Signature position"
: "Signatur position"

, "Above the quote"
: "Över citeringen"

, "Below the quote"
: "Under citeringen"

, "IMAP"
: "IMAP"

, "Host"
: "Värd"

, "Port (Default: 143 / SSL: 993)"
: "Port (Standard: 143 / SSL: 993)"

, "Secure Connection"
: "Säker anslutning"

, "None"
: "Ingen"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Användarnamn"

, "Password"
: "Lösenord"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Port (Standard: 25)"

, "Authentication"
: "Autentisering"

, "Login"
: "Logga in"

, "Plain"
: "Plain"

, "Username (optional)"
: "Användarnamn (tillval)"

, "Password (optional)"
: "Lösenord (tillval)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "Filter"

, "Port (Default: 2000)"
: "Port (Standard: 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Andra Inställningar"

, "Sent Folder Name"
: "Namn på Skickat-mapppen"

, "Trash Folder Name"
: "Namn på Skräp-mappen"

, "Drafts Folder Name"
: "Namn på Utkasts-mappen"

, "Templates Folder Name"
: "Namn på Mall-mappen"

, "Display Format"
: "Visningsformat"

, "HTML"
: "HTML"

, "Plain Text"
: "Vanlig Text"

, "Depending on content type (experimental)"
: "Beroende på innehållstyp (experimentell)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "Skapa nytt mail"

, "Toggle highlighting"
: "Växla markering"

, "Mark read/unread"
: "Markera läst/oläst"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Lägg till användare"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Id"

, "Attachments"
: "Bifogade"

, "Flags"
: "Flaggor"

, "Subject"
: "Ämne"

, "From (Email)"
: "Från (E-post)"

, "From (Name)"
: "Från (Namn)"

, "Sender"
: "Sändare"

, "To"
: "Till"

, "Sent"
: "Skickat"

, "Received"
: "Mottaget"

, "Folder, Folders"
: [
  "Mapp"
 ,"Mappar"

]
, "Size"
: "Storlek"

, "Answered"
: "Svarad"

, "Forwarded"
: "Vidarebefodrat"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "Empty Folder"
: "Tom Mapp"

, "Add Folder"
: "Lätt till Mapp"

, "New {0}"
: "Ny {0}"

, "Please enter the name of the new {0}:"
: "Ange namnet på den nya {0}:"

, "No {0} added"
: "Ingen {0} lades till"

, "You have to supply a {0} name!"
: "Du måste ange ett {0} namn!"

, "Please wait"
: "Var god vänta"

, "Creating {0}..."
: "Skapar {0} ..."

, "Edit Account"
: "Ändra Användare"

, "Edit Vacation Message"
: "Redigera Semester Meddelande"

, "Edit Filter Rules"
: "Redigera filterregler"

, "Notifications"
: ""

, "Mark Folder as read"
: "Markera mapp som läst"

, "Update Folder List"
: "Uppdatera mapp lista"

, "Message not available."
: "Meddelande är inte tillgängligt."

, "Cancel"
: "Avbryt"

, "Ok"
: "Ok"

, "Folders of account {0}"
: "Mappar av konto {0}"

, "Folders of all accounts"
: "Mappar av alla konton"

, "Compose email"
: "Skriv mail"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "Från"

, "Add"
: "Lägg till"

, "Add contact to addressbook"
: "Lägg till kontakt i adressbok"

, "Date"
: "Datum"

, "Show or hide header information"
: "Visa eller dölj rubrik-information"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(nytt meddelande)"

, "Select recipients for \"{0}\""
: "Välj mottagare för \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "Motaggar filter"

, "All recipients"
: "Alla mottagare"

, "\"{0}\" recipients"
: "\"{0}\" mottagare"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "Semester Meddelande för {0}"

, "Notification for {0}"
: ""

, "Move up"
: "Flytta upp"

, "Move down"
: "Flytta ner"

, "Enable"
: "Aktivera"

, "Disable"
: "Inaktivera"

, "ID"
: "ID"

, "Conditions"
: "Kondition"

, "Action"
: "Handling"

, "Keep a copy"
: ""

, "is greater than"
: "är större än"

, "is less than"
: "är mindre än"

, "Header \"{0}\" contains \"{1}\""
: "Huvudrubrik \"{0}\" innehåller \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "Huvudrubrik \"{0}\" matchar \"{1}\""

, "Sieve Filter Rules"
: "Sieve Filter Rules"

, "Sieve Filter Rules for {0}"
: "Sålla filter regler för {0}"

, "From (Email and Name)"
: "Från (Mail och Namn)"

, "To (Email)"
: "Till (Mail)"

, "To (Email CC)"
: ""

, "Header contains"
: "Huvudrubriks innehåll"

, "Header name"
: "Huvudrubrik namn"

, "Header value"
: "Huvudrubrik värde"

, "Header regex"
: "Huvudrubrik regex"

, "Edit Filter Rule"
: "Ändra Filter Regel"

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: "Gör denna åtgärd:"

, "Move mail to folder"
: "Flytta mail till mapp"

, "Redirect mail to address"
: "Omdirigera e-post till adress"

, "Reject mail with this text"
: "Avvisa post med denna text"

, "Discard mail"
: "kassera post"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "Behåll epost"

, "General"
: "Ällmän"

, "Advanced"
: "Avancerat"

, "Only send all X days to the same sender"
: "Bara skicka alla X dagar till samma avsändare"

, "Incoming mails will be answered with this text:"
: "Inkommande e-post kommer att besvaras med denna text:"

, "Status"
: "Status"

, "I am available (vacation message disabled)"
: "Jag är tillgänglig (semester meddelande inaktiverad)"

, "I am not available (vacation message enabled)"
: "Jag är inte tillgänglig (semester-meddelande aktiverat)"

, "Start Date"
: "Startdatum"

, "Set vacation start date ..."
: "Sätt startdatum för semester ..."

, "End Date"
: "Slutdatum"

, "Set vacation end date ..."
: "Sätt slutdatum för semester ..."

, "Representative #1"
: "Representant #1"

, "Choose first Representative ..."
: "Välj den första representanten ..."

, "Representative #2"
: "Representant #2"

, "Choose second Representative ..."
: "Välj den andra representanten ..."

, "Message Template"
: "Meddelande-mall"

, "Choose Template ..."
: "Välj mall"

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Meddelande"
 ,"Meddelanden"

]
, "Subject/From"
: "Ämne/Form"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "INBOX"
: "INKORG"

, "Drafts"
: "utkast"

, "Templates"
: "mallar"

, "Junk"
: "Skräppost"

, "Trash"
: "Skräp"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "postlista"
 ,"postlistor"

]
, "Rule, Rules"
: [
  "Regel"
 ,"Regler"

]
, "Flag, Flags"
: [
  "Flagga"
 ,"Flaggar"

]
, "Flag list, Flag lists"
: [
  "Flagg lista"
 ,"Flagg listor"

]
, "Total Messages:"
: "Totala Meddelanden: "

, "Unread Messages:"
: "Olästa Meddelanden:"

, "Name on Server:"
: "Namn på Server:"

, "Last update:"
: "Senaste uppdatering:"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "{0} oläst meddelande"
 ,"{0} olästa meddelanden"

]
, "New Mail"
: "Nytt Mail"

, "Email"
: "Mail"

, "Active Vacation Message"
: "Aktuellt semestermeddelande"

, "Email account \"{0}\" has an active vacation message."
: "E-postkonto \"{0}\" har ett aktivt semestermeddelande."

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "nya mail"

, "You got {0} new mail(s) in folder {1} ({2})."
: "Du har {0} ny mail(s) i mappen {1} ({2})."

, "IMAP Credentials for {0}"
: "IMAP Referenser för {0}"

, "Credentials"
: "Inloggningsuppgifter"

, "IMAP Error"
: "IMAP Fel"

, "No connection to IMAP server."
: "Ingen anslutning till IMAP server."

, "IMAP Credentials Error"
: "Fel på IMAP inloggningsuppgifter"

, "Your email credentials are wrong. Please contact your administrator"
: "Dina mail-inloggningsuppgifter är felaktiga. Vänligen kontakta din administratör"

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "En av dina mappar har tagits bort eller har bytts namn på av någon annan klient. Uppdatera mapplistan av detta konto."

, "SMTP Error"
: "SMTP-fel"

, "No connection to SMTP server."
: "Ingen anslutning till SMTP server"

, "Sieve Error"
: "Filterfel"

, "No connection to Sieve server."
: "Ingen anslutning till Filterserver"

, "Save Sieve Script Error"
: "Fel vid sparning av filter-skript"

, "Could not save script on Sieve server."
: "Kunde inte spara skriptet på Filterserver."

, "Add as \"To\""
: "Lägg till som \"Till\""

, "Add as \"Cc\""
: "Lägg till som \"Cc\""

, "Add as \"Bcc\""
: "Lägg till som \"Bcc\""

, "Remove from recipients"
: "Ta bort från mottagarna"

, "Loading Mail Addresses"
: "Laddar mailadresser"

, "Click here to set To/CC/BCC."
: "Klicka här för att ställa in / CC / BCC."

, "To:"
: "Till:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: "Flytta"

, "Send"
: "Skicka"

, "Search Recipients"
: "Sök mottagare"

, "Save As Draft"
: "Spara som utkast"

, "Save As Template"
: "Spara som mall"

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "Klicka här för att söka efter och lägga till mottagare från Adressboken."

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "Fwd:"

, "{0} Message"
: "{0} Meddelande"

, "Failed"
: "Misslyckades"

, "{0} account setting empty."
: "{0} kontoinställning tom."

, "Files are still uploading."
: "Filer laddas fortfarande upp."

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "På {0}, {1} skrev"

, "Original message"
: "Ursprungligt meddelande"

, "Compose email:"
: "Skriv e-post:"

, "Convert to formated text"
: ""

, "Body"
: "Layout"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: "Inget ämne"

, "Do you really want to send a message with an empty subject?"
: "Vill du verkligen skicka ett meddelande utan ämne?"

, "No recipients set."
: "Inga mottagare inställd."

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "Alla inkorgar"

, "Default Email Account"
: "Standard e-postkonto"

, "The default email account to use when sending mails."
: "Den förvalda e-post kontot för att använda när du skickar e-post."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "E-post Updaterings Intervall"

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Använd för NOTERINGAR"

, "Save Note default Value."
: "Spara Notifiering standard värde"

, "Confirm Delete"
: "bekräfta borttagning"

, "Show confirmation dialog when deleting mails."
: "Visa bekräftelseruta när du tar bort e-post."

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: "Anpassat semester-meddelande"

, "User is allowed to set custom vacation message for system account"
: "Användare tillåts sätta eget semestermeddelande för systemkonto"

, "Cache email body"
: "Lagra mails innehåll i cache"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "Skall mails innehåll lagras i cache (rekommenderas för långsamma anslutningar till IMAP-server)"

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "Frånvarande svar från %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "Seen"
: "Sett"

, "Deleted"
: "Borttagen"

, "Draft"
: "utkast"

, "Flagged"
: "Markerad"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "Alla inkorgar av mina e-postkonton"

, "All unread mail"
: "Alla olästa mail"

, "All unread mail of my email accounts"
: "Alla olästa mail av mina e-postkonton"

, "All highlighted mail"
: "Alla markerade mail"

, "All highlighted mail of my email accounts"
: "Alla markerade mail av mina e-post konton"

, "All drafts"
: "Alla utkast"

, "All mails with the draft flag"
: "Alla brev med utkast flaggning"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "Hantera email konton"

, "Edit and delete email accounts"
: "Ändra och ta bort email konton"

, "Add email accounts"
: "lägg till email konton"

, "Create new email accounts"
: "Skapa nya email konton"

, "Vacation"
: "Semester"

, "Account"
: "Konto"

, "Folder"
: "Mapp"

, "Message"
: "Meddelande"

, "record list"
: "postlista"

, "Rule"
: "Regel"

, "Flag"
: "Flagga"

, "Flag list"
: "Flagg lista"

, "{0} unread message"
: "{0} oläst meddelande"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
